CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
44 lines
1.2 KiB
C++
44 lines
1.2 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <performance_common.hh>
|
|
#include <resource_guards.hh>
|
|
|
|
class ExampleBenchmark : public Benchmark<ExampleBenchmark> {
|
|
public:
|
|
void operator()(void* dst) {
|
|
const int value = 42;
|
|
const size_t kSize = 4_MB;
|
|
|
|
TIMED_SECTION(kTimerTypeEvent) { // event based timing
|
|
HIP_CHECK(hipMemset(dst, value, kSize));
|
|
}
|
|
|
|
HIP_CHECK(hipMemset(dst, 0, kSize)); // not timed
|
|
|
|
TIMED_SECTION(kTimerTypeCpu) { // cpu based timing
|
|
HIP_CHECK(hipMemset(dst, value, kSize));
|
|
}
|
|
|
|
// accessing properties
|
|
// std::cout << "Time recorded up until now: " << time() << std::endl;
|
|
// std::cout << "Number of iterations: " << iterations() << std::endl;
|
|
// std::cout << "Number of warmup iterations: " << warmups() << std::endl;
|
|
// std::cout << "Current iteration: " << current() << std::endl;
|
|
}
|
|
};
|
|
|
|
HIP_TEST_CASE(Performance_Example) {
|
|
ExampleBenchmark benchmark;
|
|
|
|
// to override cmd options
|
|
// benchmark.Configure(10000 /* iterations */, 1000 /* warmups */);
|
|
|
|
LinearAllocGuard<void> dst(LinearAllocs::hipMalloc, 4_MB);
|
|
benchmark.Run(dst.ptr());
|
|
}
|